﻿using System;
using RestSharp;
using System.IO;
using Newtonsoft.Json;

namespace CSharp_turboSMTP_API

{
    class TurboAttachment
    {
        public string name { get; set; }
        public string type { get; set; }
        public string content { get; set; }
    }
    class TurboRequest
    {
        public string from { get; set; }
        public string to { get; set; }
        public string subject { get; set; }
        public string html_content { get; set; }
        public TurboAttachment[] attachments { get; set; }
    }
    public class TestRestSharp
    {
        public static void Main(string[] args)
        {
            string filePath = @"FILE_PATH";
            string fileName = "FILE_NAME";

            string username = "username@email.com";
            string password = "insertpasswordhere";
            string fromField = "from@email.com";
            string toField = "to@email.com";
            string subjectField = "C# Test TurboAPI Send(email) : campo SUBJECT";
            string htmlContentField = "C# Test TurboAPI Send(email) : campo HTML CONTENT";

            var client = new RestClient();
            client.BaseUrl = "https://api.turbo-smtp.com";

            var request = new RestRequest("api/mail/send", Method.POST);


            Byte[] bytes = File.ReadAllBytes(Path.Combine(filePath, fileName));
            String file = Convert.ToBase64String(bytes);

            TurboAttachment attachment = new TurboAttachment()
            {
                name = fileName, // file name
                type = "image/png", // file extension
                content = file // The Base64 encoded content of the attachment. 
            };

            TurboAttachment[] attachments = new TurboAttachment[1];
            attachments[0] = attachment;

            var body = new TurboRequest
            {
                from = fromField,
                to = toField,
                subject = subjectField,
                html_content = htmlContentField,
                attachments = attachments
            };

            var json = request.JsonSerializer.Serialize(body);


            request.AddParameter("application/json; charset=utf-8", json, ParameterType.RequestBody);

            request.AddHeader("authuser", username);
            request.AddHeader("authpass", password);

            IRestResponse response = client.Execute(request);

            var content = response.Content;

            Console.WriteLine(content);
            Console.ReadLine();
        }
    }
}
